==> nextcloud-app-mail-1.11.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
    "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
    "Creating account failed: " : "ანგარიშების შექმნა ვერ მოხერხდა:",
    "Mail" : "ფოსტა",
    "Name" : "სახელი",
    "Mail Address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Signature" : "ხელმოწერა",
    "Cancel" : "უარყოფა",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Sending …" : "იგზავნება …",
    "Go back" : "უკან დაბრუნება",
    "Retry" : "ვცადოთ ახლიდან",
    "Message sent!" : "წერილი გაგზავნილია!",
    "Send" : "გაგზავნა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "Select" : "არჩევა",
    "Choose" : "აირჩიეთ",
    "Favorites" : "რჩეულები",
    "Other" : "სხვა",
    "Reply" : "პასუხი",
    "Forward" : "წინ",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Unnamed" : "უსახელო",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "Move" : "გადატანა",
    "New message" : "ახალი წერილი",
    "Settings" : "პარამეტრები",
    "Quota" : "კვოტა",
    "Saving" : "მიმდინარეობს შენახვა",
    "Remove account" : "ანგარიშის გაუქმება",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Clear cache" : "კეშის გასუფთავება",
    "Delete" : "გაუქმება",
    "General" : "ზოგადი",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Search" : "ძიება",
    "Refresh" : "განახლება",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "All" : "ყველა",
    "Archive" : "არქივი",
    "Drafts" : "მონახაზები",
    "All inboxes" : "ყველა ინბოქსი",
    "Inbox" : "ინბოქსი",
    "Junk" : "უსარგებლო",
    "Sent" : "გაგზავნილი",
    "Trash" : "ნაგავი",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "თუ არ გსურთ ესტუმროთ იმ გვერდს, შეგიძლიათ დაუბრუნდეთ <a href=\"%s\">ფოსტას</a>.",
    "Continue to %s" : "%s-ისკენ გაგრძელება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-mail-1.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ka_GE.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "ავტო-აღმოჩენა ვერ მოხერხდა. გთხოვთ სცადოთ ხელით.",
    "Updating account failed: " : "ანგარიშის განახლება ვერ მოხერხდა:",
    "Important" : "აუცილებელი",
    "Work" : "სამსახური",
    "Personal" : "პირადი",
    "Later" : "მოგვიანებით",
    "Mail" : "ფოსტა",
    "Name" : "სახელი",
    "Mail address" : "ფოსტის მისამართი",
    "Password" : "პაროლი",
    "IMAP Host" : "IMAP ჰოსტი",
    "None" : "არც ერთი",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP პორტი",
    "IMAP User" : "IMAP მომხმარებელი",
    "IMAP Password" : "IMAP პაროლი",
    "SMTP Host" : "SMTP ჰოსტი",
    "SMTP Port" : "SMTP პორტი",
    "SMTP User" : "SMTP მომხმარებელი",
    "SMTP Password" : "SMTP პაროლი",
    "Connecting" : "მყარდება კავშირი",
    "Save" : "შენახვა",
    "Connect" : "დაკავშირება",
    "Signature" : "ხელმოწერა",
    "Cancel" : "უარყოფა",
    "Add mail account" : "საფოსტო ანგარიშის დამატება",
    "Use Gravatar and favicon avatars" : "მოიხმარეთ Gravatar და favicon ავატარები",
    "Select account" : "აირჩიეთ ანგარიში",
    "Subject" : "სათაური",
    "Upload attachment" : "დანართის ატვირთვა",
    "Add attachment from Files" : "დანართის დამატება ფაილებიდან",
    "Sending …" : "იგზავნება …",
    "Go back" : "უკან დაბრუნება",
    "Retry" : "ვცადოთ ახლიდან",
    "Message sent!" : "წერილი გაგზავნილია!",
    "Send" : "გაგზავნა",
    "Choose a file to add as attachment" : "დანართად დასამატებლად აირჩიეთ ფაილი",
    "Unfavorite" : "რჩეულებიდან ამოშლა",
    "Favorite" : "რჩეული",
    "Read" : "წაკითხვა",
    "Select" : "არჩევა",
    "Edit tags" : "შეცვალეთ ტეგები",
    "Move" : "გადატანა",
    "More actions" : "მეტი ქმედება",
    "All day" : "მთელი დღე",
    "Create" : "შექმნა",
    "Choose" : "აირჩიეთ",
    "Favorites" : "რჩეულები",
    "Other" : "სხვა",
    "Reply" : "პასუხი",
    "Forward" : "წინ",
    "Import into calendar" : "იმპორტი კალენდარში",
    "Download attachment" : "დანართის გადმოწერა",
    "Save to Files" : "შენახვა ფაილებში",
    "Unnamed" : "უსახელო",
    "Choose a folder to store the attachment in" : "გთხოვთ აირჩიოთ დირექტორია, სადაც მოთავსდება დანართი",
    "Save all to Files" : "ყველაფრის ფაილებში შენახვა",
    "The images have been blocked to protect your privacy." : "სურათები თქვენი კონფიდენციალურობის დასაცავად დაიბლოკა",
    "New message" : "ახალი წერილი",
    "Settings" : "პარამეტრები",
    "Quota" : "კვოტა",
    "Saving" : "მიმდინარეობს შენახვა",
    "Remove account" : "ანგარიშის გაუქმება",
    "Mark all as read" : "ყველას წაკითხულად მონიშვნა",
    "Clear cache" : "კეშის გასუფთავება",
    "Delete" : "გაუქმება",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Add" : "დამატება",
    "Disabled" : "არაა მოქმედი",
    "Enabled" : "მოქმედია",
    "Custom" : "ინდივიდუალური",
    "Add tag" : "ტეგის დამატება",
    "Remove" : "წაშლა",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "General" : "ზოგადი",
    "User" : "მომხმარებელი",
    "Host" : "ჰოსტი",
    "Port" : "პორტი",
    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Speed up your Mail experience with these quick shortcuts." : "მოიხმარეთ ეს კომბინაციები ფოსტასთან უფრო სწრაფად სამუშაოდ.",
    "Compose new message" : "ახალი წერილის შედგენა",
    "Newer message" : "უფრო ახალი წერილი",
    "Older message" : "ძველი წერილი",
    "Toggle star" : "ვარსკლავის გადართვა",
    "Toggle unread" : "წაუკითხავის გადართვა",
    "Search" : "ძიება",
    "Refresh" : "განახლება",
    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
    "All" : "ყველა",
    "Archive" : "არქივი",
    "Drafts" : "მონახაზები",
    "All inboxes" : "ყველა ინბოქსი",
    "Inbox" : "ინბოქსი",
    "Junk" : "უსარგებლო",
    "Sent" : "გაგზავნილი",
    "Trash" : "ნაგავი",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ახალი წერილი\n{from}-ისგან","%n ახალი წერილი\n{from}-ისგან"],
    "Nextcloud Mail" : "Nextcloud ფოსტა",
    "Message sent" : "წერილი გაგზავნილია",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ვერ ჩაიტვირთა",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}-ის ჩატვირთვისას მოხდა შეცდომა",
    "Could not load your message" : "თქვენი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the desired message" : "სასურველი წერილის ჩატვირთვა ვერ მოხერხდა",
    "Could not load the message" : "წერილის ჩატვირთვა ვერ მოხერხდა",
    "Error loading message" : "წერილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Forwarding to %s" : "გადაგზავნილია %s-ზე",
    "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
    "Redirect" : "გადამისამართება",
    "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "თუ არ გსურთ ესტუმროთ იმ გვერდს, შეგიძლიათ დაუბრუნდეთ <a href=\"%s\">ფოსტას</a>.",
    "Continue to %s" : "%s-ისკენ გაგრძელება"
},
"nplurals=2; plural=(n!=1);");
